@@ -21,7 +21,7 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <klocale.h>
+#include <tdelocale.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -618,7 +618,7 @@ MyMoneyAccount MyMoneySchedule::account(int cnt) const
       if(!cnt)
         return acc;
     } catch(MyMoneyException *e) {
-      qWarning("Schedule '%s' references unknown account '%s'", id().data(),   (*it).accountId().data());
+      tqWarning("Schedule '%s' references unknown account '%s'", id().data(),   (*it).accountId().data());
       delete e;
       return MyMoneyAccount();
     }
@@ -1062,7 +1062,7 @@ int MyMoneySchedule::eventsPerYear(MyMoneySchedule::occurenceE occurence)
       rc = 1;
       break;
     default:
-      qWarning("Occurence not supported by financial calculator");
+      tqWarning("Occurence not supported by financial calculator");
   }
 
   return rc;
@@ -1120,7 +1120,7 @@ int MyMoneySchedule::daysBetweenEvents(MyMoneySchedule::occurenceE occurence)
       rc = 360;
       break;
     default:
-      qWarning("Occurence not supported by financial calculator");
+      tqWarning("Occurence not supported by financial calculator");
   }
 
  return rc;
