@@ -20,17 +20,17 @@
 #include <tqfile.h>
 
 #include <kdebug.h>
-#include <kdeversion.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <klocale.h>
+#include <tdeversion.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 
 #include "querytabletest.h"
 #include "reportstestcommon.h"
 
 #define private public
-#include "tquerytable.h"
+#include "querytable.h"
 #undef private
 
 #include "../mymoney/mymoneyaccount.h"
@@ -646,8 +646,8 @@ void QueryTableTest::testInvestment(void)
       CPPUNIT_ASSERT(rows.count() == 16);
 
       //this is to make sure that the dates of closing and opening balances and the balance numbers are ok
-      TQString openingDate = KGlobal::locale()->formatDate(TQDate(2004,1,1), true);
-      TQString closingDate = KGlobal::locale()->formatDate(TQDate(2005,9,1), true);
+      TQString openingDate = TDEGlobal::locale()->formatDate(TQDate(2004,1,1), true);
+      TQString closingDate = TDEGlobal::locale()->formatDate(TQDate(2005,9,1), true);
       CPPUNIT_ASSERT( html.find(openingDate + "</td><td class=\"left\"></td><td class=\"left\">"+i18n("Opening Balance")) > 0);
       CPPUNIT_ASSERT( html.find(closingDate + "</td><td class=\"left\"></td><td class=\"left\">"+i18n("Closing Balance")+"</td><td class=\"left\"></td><td class=\"value\"></td><td>&nbsp;-702.36</td></tr>") > 0);
       CPPUNIT_ASSERT( html.find(closingDate + "</td><td class=\"left\"></td><td class=\"left\">"+i18n("Closing Balance")+"</td><td class=\"left\"></td><td class=\"value\"></td><td>&nbsp;-705.69</td></tr>") > 0);
