@@ -25,8 +25,8 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kiconloader.h>
 #include <kdebug.h>
 
@@ -212,7 +212,7 @@ void Transaction::markAttachment(TQPainter* painter, int /* row */, int /* col *
 
   painter->save();
   if(clip.isNull()) {
-    clip = KGlobal::iconLoader()->loadIcon("attach", KIcon::Small, KIcon::SizeSmall, KIcon::DefaultState);
+    clip = TDEGlobal::iconLoader()->loadIcon("attach", TDEIcon::Small, TDEIcon::SizeSmall, TDEIcon::DefaultState);
     if(clip.height() > h) {
       clip.resize(h, h);
     }
@@ -615,7 +615,7 @@ void Transaction::arrangeWidget(TQTable* tbl, int row, int col, TQWidget* w) con
     // events will be directed to the edit widget
     w->removeEventFilter(tbl);
   } else
-    qDebug("No widget for %d,%d", row, col);
+    tqDebug("No widget for %d,%d", row, col);
 }
 
 bool Transaction::haveNumberField(void) const
@@ -658,10 +658,10 @@ bool Transaction::maybeTip(const TQPoint& cpos, int row, int col, TQRect& r, TQS
 
   // check for detail column in row 0 of the transaction for a possible exclamation mark
   r = m_parent->cellGeometry(m_startRow + 0, col);
-  // qDebug("r is %d,%d,%d,%d", r.x(), r.y(), r.width(), r.height());
+  // tqDebug("r is %d,%d,%d,%d", r.x(), r.y(), r.width(), r.height());
   r.setBottomLeft(TQPoint(r.x() + (r.width() - h), r.y() + h));
-  // qDebug("r is %d,%d,%d,%d", r.x(), r.y(), r.width(), r.height());
-  // qDebug("p is in r = %d", r.contains(cpos));
+  // tqDebug("r is %d,%d,%d,%d", r.x(), r.y(), r.width(), r.height());
+  // tqDebug("p is in r = %d", r.contains(cpos));
   if(r.contains(cpos) && m_erronous) {
     if(m_transaction.splits().count() < 2) {
       msg = TQString("<qt>%1</qt>").arg(i18n("Transaction is missing a category assignment."));
@@ -1029,7 +1029,7 @@ bool StdTransaction::formCellText(TQString& txt, int& align, int row, int col, T
           case ValueColumn2:
             align |= TQt::AlignRight;
             if(m_transaction != MyMoneyTransaction())
-              txt = KGlobal::locale()->formatDate(m_transaction.postDate(), true);
+              txt = TDEGlobal::locale()->formatDate(m_transaction.postDate(), true);
             break;
         }
         break;
@@ -1096,7 +1096,7 @@ void StdTransaction::registerCellText(TQString& txt, int& align, int row, int co
 
         case DateColumn:
           align |= TQt::AlignLeft;
-          txt = KGlobal::locale()->formatDate(m_transaction.postDate(), true);
+          txt = TDEGlobal::locale()->formatDate(m_transaction.postDate(), true);
           break;
 
         case DetailColumn:
@@ -1500,7 +1500,7 @@ bool InvestTransaction::formCellText(TQString& txt, int& align, int row, int col
           align |= TQt::AlignRight;
           fieldEditable = true;
           if(m_transaction != MyMoneyTransaction())
-            txt = KGlobal::locale()->formatDate(m_transaction.postDate(), true);
+            txt = TDEGlobal::locale()->formatDate(m_transaction.postDate(), true);
           break;
       }
       break;
@@ -1688,7 +1688,7 @@ void InvestTransaction::registerCellText(TQString& txt, int& align, int row, int
       switch(col) {
         case DateColumn:
           align |= TQt::AlignLeft;
-          txt = KGlobal::locale()->formatDate(m_transaction.postDate(), true);
+          txt = TDEGlobal::locale()->formatDate(m_transaction.postDate(), true);
           break;
 
         case DetailColumn:
